Learn R Programming

tm.plugin.webmining (version 1.1)

GoogleBlogSearchSource: Get feed data from Google Blog Search (http://www.google.com/blogsearch).

Description

Google Blog Search is a specialized search service/index for web blogs. Since the Googlebots are typically just scanning the blog's RSS feeds for updates they are much faster updating than comparable general purpose crawlers.

Usage

GoogleBlogSearchSource(query, params = list(hl = "en", q = query, ie =
  "utf-8", num = 100, output = "rss"), ...)

Arguments

query
Google Blog Search query
params,
additional query parameters
...
additional parameters to WebSource

Value

  • WebXMLSource

See Also

WebSource

Examples

Run this code
corpus <- Corpus(GoogleBlogSearchSource("Microsoft"))

Run the code above in your browser using DataLab