YahooFinanceSource: Get feed data from Yahoo! Finance.
Description
Yahoo! Finance is a popular site which provides financial news and information. It is a large source
for historical price data as well as financial news. Using the typical Yahoo! Finance ticker
news items can easily be retrieved. However, the maximum number of items is 20.
Usage
YahooFinanceSource(query, params = list(s = query, n = 20), ...)
Arguments
query
ticker symbols of companies to be searched for, see http://finance.yahoo.com/lookup.
params,
additional query parameters, see http://developer.yahoo.com/rss/