Learn R Programming

tm.plugin.webmining (version 0.9)

YahooNewsSource: Get feed data from Yahoo! News (http://news.yahoo.com/).

Description

Yahoo! News is a large news aggregator and provides a customizable RSS feed. Only a maximum of 20 items can be retrieved.

Usage

YahooNewsSource(query,
    params = list(p = query, n = 20, ei = "UTF-8"), ...)

Arguments

query
words to be searched in Yahoo News, multiple words must be separated by '+'
params,
additional query parameters, see http://developer.yahoo.com/rss/
...
additional parameters to WebSource

Value

  • WebXMLSource

See Also

WebSource

Examples

Run this code
corpus <- Corpus(YahooNewsSource("Microsoft"))

Run the code above in your browser using DataLab