Learn R Programming

tm.plugin.webmining (version 0.9)

corpus.update: Update/Extend WebCorpus with new feed items.

Description

The corpus.update method ensures, that the original WebCorpus feed sources are downloaded and checked against already included TextDocuments. Based on the ID included in the TextDocument's meta data, only new feed elements are downloaded and added to the WebCorpus. All relevant information regariding the original source feeds are stored in the WebCorpus' meta data (CMetaData).

Usage

corpus.update(x, ...)

Arguments

x
object of type WebCorpus
...
[object Object],[object Object],[object Object]