Learn R Programming

tm.plugin.webmining (version 1.2.2)

parse: Wrapper/Convenience function to ensure right encoding for different Platforms

Description

Depending on specified type one of the following parser functions is called: [object Object],[object Object],[object Object]

Usage

parse(..., asText = TRUE, type = c("XML", "HTML", "JSON"))

Arguments

...
arguments to be passed to specified parser function
asText
defines if input should be treated as text/character, default to TRUE
type
either "XML", "HTML" or "JSON". Defaults to "XML"