Learn R Programming

tm.plugin.webmining (version 1.2.2)

tm.plugin.webmining-package: Retrieve structured, textual data from various web sources

Description

tm.plugin.webmining facilitates the retrieval of textual data through various web feed formats like XML and JSON. Also direct retrieval from HTML is supported. As most (news) feeds only incorporate small fractions of the original text tm.plugin.webmining goes a step further and even retrieves and extracts the text of the original text source. Generally, the retrieval procedure can be described as a two--step process: [object Object],[object Object]

Arguments

See Also

WebCorpus GoogleFinanceSource GoogleNewsSource NYTimesSource ReutersNewsSource YahooFinanceSource YahooInplaySource YahooNewsSource

Examples

Run this code
googlefinance <- WebCorpus(GoogleFinanceSource("NASDAQ:MSFT"))
googlenews <- WebCorpus(GoogleNewsSource("Microsoft"))
nytimes <- WebCorpus(NYTimesSource("Microsoft", appid = nytimes_appid))
reutersnews <- WebCorpus(ReutersNewsSource("businessNews"))
yahoofinance <- WebCorpus(YahooFinanceSource("MSFT"))
yahooinplay <- WebCorpus(YahooInplaySource())
yahoonews <- WebCorpus(YahooNewsSource("Microsoft"))

Run the code above in your browser using DataLab